@@ -1,4 +1,4 @@
-import GL
+from pygl_nf import GL
 
 win = GL.Display_init(flags=GL.Full)
 
