@@ -1,11 +1,17 @@
-import GL
+from pygl_nf import GL
 
-GL.Widgets_().Get_Print_Widgets(True)
+import time
+
+
+GL.Widgets_().Get_Print_Widgets()
 
 win = GL.Display_init(
     flags=GL.Full
 )
 
+startTime = time.time()
+
+
 
 text_box = GL.Widgets_.TextBoxs(
     win.screen,
@@ -13,7 +19,7 @@ text_box = GL.Widgets_.TextBoxs(
     50,
     (200,200,200),
     (100,100,100),
-    GL.passing,
+    GL.Passing,
     10
 )
 
@@ -23,11 +29,11 @@ button = GL.Widgets_.Buttons(
     'Click',(20,180,60),
     60,60,
     (100,50,200),(60,60,170),(120,60,160),
-    10,GL.passing,
+    10,GL.Passing,
     10,(100,100,100)
 )
 
-drop_down = GL.Widgets_.Dropdowns(
+drop_down = GL.Widgets_.DropDowns(
     win.screen,
     [650,10],[180,60],
     'Colors',
@@ -70,7 +76,10 @@ slider = GL.Widgets_.Sliders(
     0,200,
     1,(100,200,160),(60,220,180)
 )
-
+GL.Progress_bar_time = 20
+progressbar = GL.Widgets_.ProgressBar(
+    win.screen,
+    [100,700],[300,50],GL.Progres_bar_buffer,Curved=True)
 
 
 def App():
@@ -82,6 +91,8 @@ def App():
         drop_down.Update()
         toggle.Update()
         slider.Update()
+        progressbar.Update()
+        text_box.Set_text(str(progressbar.Get_prcent()))
 
 if __name__ == '__main__':
     App()
